# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvcs.endpoint import endpoint_data

class AddDeviceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'AddDevice','vcs')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_DeviceSite(self):
		return self.get_body_params().get('DeviceSite')

	def set_DeviceSite(self,DeviceSite):
		self.add_body_params('DeviceSite', DeviceSite)

	def get_CorpId(self):
		return self.get_body_params().get('CorpId')

	def set_CorpId(self,CorpId):
		self.add_body_params('CorpId', CorpId)

	def get_GbId(self):
		return self.get_body_params().get('GbId')

	def set_GbId(self,GbId):
		self.add_body_params('GbId', GbId)

	def get_BitRate(self):
		return self.get_body_params().get('BitRate')

	def set_BitRate(self,BitRate):
		self.add_body_params('BitRate', BitRate)

	def get_DeviceDirection(self):
		return self.get_body_params().get('DeviceDirection')

	def set_DeviceDirection(self,DeviceDirection):
		self.add_body_params('DeviceDirection', DeviceDirection)

	def get_DeviceAddress(self):
		return self.get_body_params().get('DeviceAddress')

	def set_DeviceAddress(self,DeviceAddress):
		self.add_body_params('DeviceAddress', DeviceAddress)

	def get_DeviceType(self):
		return self.get_body_params().get('DeviceType')

	def set_DeviceType(self,DeviceType):
		self.add_body_params('DeviceType', DeviceType)

	def get_DeviceResolution(self):
		return self.get_body_params().get('DeviceResolution')

	def set_DeviceResolution(self,DeviceResolution):
		self.add_body_params('DeviceResolution', DeviceResolution)

	def get_Vendor(self):
		return self.get_body_params().get('Vendor')

	def set_Vendor(self,Vendor):
		self.add_body_params('Vendor', Vendor)

	def get_DeviceName(self):
		return self.get_body_params().get('DeviceName')

	def set_DeviceName(self,DeviceName):
		self.add_body_params('DeviceName', DeviceName)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvcs.endpoint import endpoint_data

class UpdateMonitorRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'UpdateMonitor','vcs')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_CorpId(self):
		return self.get_body_params().get('CorpId')

	def set_CorpId(self,CorpId):
		self.add_body_params('CorpId', CorpId)

	def get_Description(self):
		return self.get_body_params().get('Description')

	def set_Description(self,Description):
		self.add_body_params('Description', Description)

	def get_RuleName(self):
		return self.get_body_params().get('RuleName')

	def set_RuleName(self,RuleName):
		self.add_body_params('RuleName', RuleName)

	def get_PicOperateType(self):
		return self.get_body_params().get('PicOperateType')

	def set_PicOperateType(self,PicOperateType):
		self.add_body_params('PicOperateType', PicOperateType)

	def get_AttributeName(self):
		return self.get_body_params().get('AttributeName')

	def set_AttributeName(self,AttributeName):
		self.add_body_params('AttributeName', AttributeName)

	def get_AttributeOperateType(self):
		return self.get_body_params().get('AttributeOperateType')

	def set_AttributeOperateType(self,AttributeOperateType):
		self.add_body_params('AttributeOperateType', AttributeOperateType)

	def get_RuleExpression(self):
		return self.get_body_params().get('RuleExpression')

	def set_RuleExpression(self,RuleExpression):
		self.add_body_params('RuleExpression', RuleExpression)

	def get_TaskId(self):
		return self.get_body_params().get('TaskId')

	def set_TaskId(self,TaskId):
		self.add_body_params('TaskId', TaskId)

	def get_DeviceOperateType(self):
		return self.get_body_params().get('DeviceOperateType')

	def set_DeviceOperateType(self,DeviceOperateType):
		self.add_body_params('DeviceOperateType', DeviceOperateType)

	def get_PicList(self):
		return self.get_body_params().get('PicList')

	def set_PicList(self,PicList):
		self.add_body_params('PicList', PicList)

	def get_AttributeValueList(self):
		return self.get_body_params().get('AttributeValueList')

	def set_AttributeValueList(self,AttributeValueList):
		self.add_body_params('AttributeValueList', AttributeValueList)

	def get_DeviceList(self):
		return self.get_body_params().get('DeviceList')

	def set_DeviceList(self,DeviceList):
		self.add_body_params('DeviceList', DeviceList)

	def get_AlgorithmVendor(self):
		return self.get_body_params().get('AlgorithmVendor')

	def set_AlgorithmVendor(self,AlgorithmVendor):
		self.add_body_params('AlgorithmVendor', AlgorithmVendor)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvcs.endpoint import endpoint_data

class ReportDeviceCapacityRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'ReportDeviceCapacity','vcs')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_StreamCapacitiess(self):
		return self.get_body_params().get('StreamCapacitiess')

	def set_StreamCapacitiess(self, StreamCapacitiess):
		for depth1 in range(len(StreamCapacitiess)):
			if StreamCapacitiess[depth1].get('BitrateRange') is not None:
				self.add_body_params('StreamCapacities.' + str(depth1 + 1) + '.BitrateRange', StreamCapacitiess[depth1].get('BitrateRange'))
			if StreamCapacitiess[depth1].get('MaxStream') is not None:
				self.add_body_params('StreamCapacities.' + str(depth1 + 1) + '.MaxStream', StreamCapacitiess[depth1].get('MaxStream'))
			if StreamCapacitiess[depth1].get('EncodeFormat') is not None:
				self.add_body_params('StreamCapacities.' + str(depth1 + 1) + '.EncodeFormat', StreamCapacitiess[depth1].get('EncodeFormat'))
			if StreamCapacitiess[depth1].get('MaxFrameRate') is not None:
				self.add_body_params('StreamCapacities.' + str(depth1 + 1) + '.MaxFrameRate', StreamCapacitiess[depth1].get('MaxFrameRate'))
			if StreamCapacitiess[depth1].get('Resolution') is not None:
				self.add_body_params('StreamCapacities.' + str(depth1 + 1) + '.Resolution', StreamCapacitiess[depth1].get('Resolution'))

	def get_Latitude(self):
		return self.get_body_params().get('Latitude')

	def set_Latitude(self,Latitude):
		self.add_body_params('Latitude', Latitude)

	def get_PresetNum(self):
		return self.get_body_params().get('PresetNum')

	def set_PresetNum(self,PresetNum):
		self.add_body_params('PresetNum', PresetNum)

	def get_DeviceSn(self):
		return self.get_body_params().get('DeviceSn')

	def set_DeviceSn(self,DeviceSn):
		self.add_body_params('DeviceSn', DeviceSn)

	def get_AudioFormat(self):
		return self.get_body_params().get('AudioFormat')

	def set_AudioFormat(self,AudioFormat):
		self.add_body_params('AudioFormat', AudioFormat)

	def get_PTZCapacity(self):
		return self.get_body_params().get('PTZCapacity')

	def set_PTZCapacity(self,PTZCapacity):
		self.add_body_params('PTZCapacity', PTZCapacity)

	def get_Longitude(self):
		return self.get_body_params().get('Longitude')

	def set_Longitude(self,Longitude):
		self.add_body_params('Longitude', Longitude)